==> suricata-debug-6.0.18-1-x86_64.pkg.tar.zst: usr/src/debug/suricata/suricata-6.0.18/src/build-info.h <==
printf(
"Suricata Configuration:\n"
"  AF_PACKET support:                       yes\n"
"  eBPF support:                            no\n"
"  XDP support:                             no\n"
"  PF_RING support:                         no\n"
"  NFQueue support:                         yes\n"
"  NFLOG support:                           yes\n"
"  IPFW support:                            no\n"
"  Netmap support:                          no  using new api: no\n"
"  DAG enabled:                             no\n"
"  Napatech enabled:                        no\n"
"  WinDivert enabled:                       no\n"
"\n"
"  Unix socket enabled:                     yes\n"
"  Detection enabled:                       yes\n"
"\n"
"  Libmagic support:                        yes\n"
"  libnss support:                          yes\n"
"  libnspr support:                         yes\n"
"  libjansson support:                      yes\n"
"  hiredis support:                         no\n"
"  hiredis async with libevent:             no\n"
"  Prelude support:                         no\n"
"  PCRE jit:                                yes\n"
"  LUA support:                             yes, through luajit\n"
"  libluajit:                               yes\n"
"  GeoIP2 support:                          yes\n"
"  Non-bundled htp:                         no\n"
"  Hyperscan support:                       no\n"
"  Libnet support:                          yes\n"
"  liblz4 support:                          yes\n"
"  HTTP2 decompression:                     no\n"
"\n"
"  Rust support:                            yes\n"
"  Rust strict mode:                        no\n"
"  Rust compiler path:                      /usr/bin/rustc\n"
"  Rust compiler version:                   rustc 1.77.1 (7cf61ebde 2024-03-27) (Arch Linux rust 1:1.77.1-1)\n"
"  Cargo path:                              /usr/bin/cargo\n"
"  Cargo version:                           cargo 1.77.1\n"
"  Cargo vendor:                            yes\n"
"\n"
"  Python support:                          yes\n"
"  Python path:                             /usr/bin/python3\n"
"  Install suricatactl:                     yes\n"
"  Install suricatasc:                      yes\n"
"  Install suricata-update:                 yes\n"
"\n"
"  Profiling enabled:                       no\n"
"  Profiling locks enabled:                 no\n"
"\n"
"  Plugin support (experimental):           yes\n"
"\n"
"Development settings:\n"
"  Coccinelle / spatch:                     no\n"
"  Unit tests enabled:                      no\n"
"  Debug output enabled:                    no\n"
"  Debug validation enabled:                no\n"
"\n"
"Generic build parameters:\n"
"  Installation prefix:                     /usr\n"
"  Configuration directory:                 /etc/suricata/\n"
"  Log directory:                           /var/log/suricata/\n"
"\n"
"  --prefix                                 /usr\n"
"  --sysconfdir                             /etc\n"
"  --localstatedir                          /var\n"
"  --datarootdir                            /usr/share\n"
"\n"
"  Host:                                    x86_64-pc-linux-gnu\n"
"  Compiler:                                gcc (exec name) / g++ (real)\n"
"  GCC Protect enabled:                     yes\n"
"  GCC march native enabled:                yes\n"
"  GCC Profile enabled:                     no\n"
"  Position Independent Executable enabled: no\n"
"  CFLAGS                                   -march=x86-64 -mtune=generic -O2 -pipe -fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat -Werror=format-security         -fstack-clash-protection -fcf-protection -g -ffile-prefix-map=/build/suricata/src=/usr/src/debug/suricata -flto=auto -std=c11 -march=native -I${srcdir}/../rust/gen -I${srcdir}/../rust/dist\n"
"  PCAP_CFLAGS                               -I/usr/include\n"
"  SECCFLAGS                                -fstack-protector -D_FORTIFY_SOURCE=2 -Wformat -Wformat-security\n"
);

==> suricata-debug-6.0.19-1-x86_64.pkg.tar.zst: usr/src/debug/suricata/suricata-6.0.19/src/build-info.h <==
printf(
"Suricata Configuration:\n"
"  AF_PACKET support:                       yes\n"
"  eBPF support:                            no\n"
"  XDP support:                             no\n"
"  PF_RING support:                         no\n"
"  NFQueue support:                         yes\n"
"  NFLOG support:                           yes\n"
"  IPFW support:                            no\n"
"  Netmap support:                          no  using new api: no\n"
"  DAG enabled:                             no\n"
"  Napatech enabled:                        no\n"
"  WinDivert enabled:                       no\n"
"\n"
"  Unix socket enabled:                     yes\n"
"  Detection enabled:                       yes\n"
"\n"
"  Libmagic support:                        yes\n"
"  libnss support:                          yes\n"
"  libnspr support:                         yes\n"
"  libjansson support:                      yes\n"
"  hiredis support:                         no\n"
"  hiredis async with libevent:             no\n"
"  Prelude support:                         no\n"
"  PCRE jit:                                yes\n"
"  LUA support:                             yes, through luajit\n"
"  libluajit:                               yes\n"
"  GeoIP2 support:                          yes\n"
"  Non-bundled htp:                         no\n"
"  Hyperscan support:                       no\n"
"  Libnet support:                          yes\n"
"  liblz4 support:                          yes\n"
"  HTTP2 decompression:                     no\n"
"\n"
"  Rust support:                            yes\n"
"  Rust strict mode:                        no\n"
"  Rust compiler path:                      /usr/bin/rustc\n"
"  Rust compiler version:                   rustc 1.78.0 (9b00956e5 2024-04-29) (Arch Linux rust 1:1.78.0-1)\n"
"  Cargo path:                              /usr/bin/cargo\n"
"  Cargo version:                           cargo 1.78.0\n"
"  Cargo vendor:                            yes\n"
"\n"
"  Python support:                          yes\n"
"  Python path:                             /usr/bin/python3\n"
"  Install suricatactl:                     yes\n"
"  Install suricatasc:                      yes\n"
"  Install suricata-update:                 yes\n"
"\n"
"  Profiling enabled:                       no\n"
"  Profiling locks enabled:                 no\n"
"\n"
"  Plugin support (experimental):           yes\n"
"\n"
"Development settings:\n"
"  Coccinelle / spatch:                     no\n"
"  Unit tests enabled:                      no\n"
"  Debug output enabled:                    no\n"
"  Debug validation enabled:                no\n"
"\n"
"Generic build parameters:\n"
"  Installation prefix:                     /usr\n"
"  Configuration directory:                 /etc/suricata/\n"
"  Log directory:                           /var/log/suricata/\n"
"\n"
"  --prefix                                 /usr\n"
"  --sysconfdir                             /etc\n"
"  --localstatedir                          /var\n"
"  --datarootdir                            /usr/share\n"
"\n"
"  Host:                                    x86_64-pc-linux-gnu\n"
"  Compiler:                                gcc (exec name) / g++ (real)\n"
"  GCC Protect enabled:                     yes\n"
"  GCC march native enabled:                yes\n"
"  GCC Profile enabled:                     no\n"
"  Position Independent Executable enabled: no\n"
"  CFLAGS                                   -march=x86-64 -mtune=generic -O2 -pipe -fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=3 -Wformat -Werror=format-security         -fstack-clash-protection -fcf-protection         -fno-omit-frame-pointer -mno-omit-leaf-frame-pointer -g -ffile-prefix-map=/build/suricata/src=/usr/src/debug/suricata -flto=auto -std=c11 -march=native -I${srcdir}/../rust/gen -I${srcdir}/../rust/dist\n"
"  PCAP_CFLAGS                               -I/usr/include\n"
"  SECCFLAGS                                -fstack-protector -D_FORTIFY_SOURCE=2 -Wformat -Wformat-security\n"
);
